@@ -1685,10 +1685,10 @@ static gboolean notify_daemon_get_server_information (NotifyDaemonNotifications
 {
 	notify_daemon_notifications_complete_get_server_information(object,
 			invocation,
-			g_strdup("Notification Daemon"),
-			g_strdup("MATE"),
-			g_strdup(PACKAGE_VERSION),
-			g_strdup("1.1"));
+			"Notification Daemon",
+			"MATE",
+			PACKAGE_VERSION,
+			"1.1");
 	return TRUE;
 }
 
