@@ -4,6 +4,7 @@
  * Copyright (C) 2005 John (J5) Palmieri <johnp@redhat.com>
  * Copyright (C) 2010 Red Hat, Inc.
  * Copyright (C) 2011 Perberos <perberos@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +27,11 @@
 #include "daemon.h"
 #include "engines.h"
 
+#ifdef HAVE_WAYLAND
+#include <gdk/gdkwayland.h>
+#include "wayland.h"
+#endif /* HAVE_WAYLAND */
+
 typedef struct {
 	GModule*    module;
 	guint       ref_count;
@@ -50,7 +56,7 @@ typedef struct {
 
 } ThemeEngine;
 
-static guint        theme_prop_notify_id = 0;
+static gulong       theme_prop_notify_id = 0;
 static ThemeEngine* active_engine = NULL;
 
 static ThemeEngine* load_theme_engine(const char *name)
@@ -176,7 +182,7 @@ static ThemeEngine* get_theme_engine(void)
 		}
 
 		char* enginename = g_settings_get_string(gsettings, GSETTINGS_KEY_THEME);
-		if (enginename == NULL)
+		if (enginename == NULL || *enginename == '\0')
 		{
 			active_engine = load_theme_engine("standard");
 			g_assert(active_engine != NULL);
@@ -191,10 +197,10 @@ static ThemeEngine* get_theme_engine(void)
 				active_engine = load_theme_engine("standard");
 			}
 
-			g_free(enginename);
-
 			g_assert(active_engine != NULL);
 		}
+
+		g_free(enginename);
 	}
 
 	return active_engine;
@@ -206,6 +212,12 @@ GtkWindow* theme_create_notification(UrlClickedCb url_clicked_cb)
 	GtkWindow* nw = engine->create_notification(url_clicked_cb);
 	g_object_set_data_full(G_OBJECT(nw), "_theme_engine", engine, (GDestroyNotify) theme_engine_unref);
 	engine->ref_count++;
+#if HAVE_WAYLAND
+	if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+	{
+		wayland_init_notification (nw);
+	}
+#endif /* HAVE_WAYLAND */
 	return nw;
 }
 
@@ -313,6 +325,12 @@ void theme_clear_notification_actions(GtkWindow* nw)
 
 void theme_move_notification(GtkWindow* nw, int x, int y)
 {
+#if HAVE_WAYLAND
+	if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+	{
+		wayland_move_notification (nw, x, y);
+	}
+#endif /* HAVE_WAYLAND */
 	ThemeEngine* engine = g_object_get_data(G_OBJECT(nw), "_theme_engine");
 	engine->move_notification(nw, x, y);
 }
