@@ -4,6 +4,7 @@
  *
  * Copyright (C) 2012 - Stefano Karapetsas <stefano@karapetsas.com>
  * Copyright (C) 2008 - Martin Sourada
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * notification-daemon-engine-nodoka is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General Public License as
@@ -27,7 +28,6 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
 
 #include <libxml/xpath.h>
 
@@ -133,18 +133,30 @@ activate_link (GtkLabel *label, const char *url, WindowData *windata)
 	return TRUE;
 }
 
+static void
+get_size_of_widgets_monitor(GtkWidget *widget, int *width, int *height)
+{
+	GdkWindow *window = gtk_widget_get_window (widget);
+	GdkMonitor *monitor = gdk_display_get_monitor_at_window (
+			gdk_window_get_display (window),
+			window);
+	GdkRectangle workarea;
+	gdk_monitor_get_workarea (monitor, &workarea);
+	if (width)  *width  = workarea.width;
+	if (height) *height = workarea.height;
+}
+
 /* Set if we have arrow down or arrow up */
 static GtkArrowType
 get_notification_arrow_type(GtkWidget *nw)
 {
 	WindowData *windata = g_object_get_data(G_OBJECT(nw), "windata");
-	int screen_height;
+	int monitor_height;
 
-	screen_height = HeightOfScreen (gdk_x11_screen_get_xscreen (
-		gdk_window_get_screen (gtk_widget_get_window (nw))));
+	get_size_of_widgets_monitor (nw, NULL, &monitor_height);
 
 	if (windata->arrow.position.y + windata->height + DEFAULT_ARROW_HEIGHT >
-		screen_height)
+		monitor_height)
 	{
 		return GTK_ARROW_DOWN;
 	}
@@ -158,12 +170,11 @@ get_notification_arrow_type(GtkWidget *nw)
 static void
 set_arrow_parameters (WindowData *windata)
 {
-	int screen_width;
+	int monitor_width;
 	int x,y;
 	GtkArrowType arrow_type;
 
-	screen_width = WidthOfScreen (gdk_x11_screen_get_xscreen (
-		gdk_window_get_screen (gtk_widget_get_window (windata->win))));
+	get_size_of_widgets_monitor (windata->win, &monitor_width, NULL);
 
 	/* Set arrow offset */
 	GtkAllocation alloc;
@@ -171,11 +182,11 @@ set_arrow_parameters (WindowData *windata)
 
 	if ((windata->arrow.position.x - DEFAULT_ARROW_SKEW -
 		DEFAULT_ARROW_OFFSET + alloc.width) >
-			screen_width)
+			monitor_width)
 	{
 		windata->arrow.offset = windata->arrow.position.x -
 					DEFAULT_ARROW_SKEW -
-					(screen_width -
+					(monitor_width -
 						alloc.width);
 	}
 	else if ((windata->arrow.position.x - DEFAULT_ARROW_SKEW -
@@ -322,12 +333,12 @@ nodoka_rounded_rectangle_with_arrow (cairo_t * cr,
 
 	cairo_rectangle_int_t rect;
 	rect.x = 0;
-	rect.width = w;
+	rect.width = (int)w;
 	if (arrow_up)
 		rect.y = 0 + DEFAULT_ARROW_HEIGHT;
 	else
 		rect.y = 0;
-	rect.height = h - DEFAULT_ARROW_HEIGHT;
+	rect.height = (int)(h - DEFAULT_ARROW_HEIGHT);
 
 	cairo_move_to (cr, rect.x + radius, rect.y);
 
@@ -369,7 +380,7 @@ nodoka_rounded_rectangle_with_arrow (cairo_t * cr,
 static void
 fill_background(GtkWidget *widget, WindowData *windata, cairo_t *cr)
 {
-	float alpha;
+	double alpha;
 	if (windata->composited)
 		alpha = BACKGROUND_OPACITY;
 	else
@@ -405,7 +416,7 @@ draw_stripe(GtkWidget *widget, WindowData *windata, cairo_t *cr)
 	GdkRGBA  center_color;
 	GdkRGBA  bottom_color;
 
-	float alpha;
+	double alpha;
 	if (windata->composited)
 		alpha = BACKGROUND_OPACITY;
 	else
@@ -475,7 +486,7 @@ draw_stripe(GtkWidget *widget, WindowData *windata, cairo_t *cr)
 static void
 draw_border(GtkWidget *widget, WindowData *windata, cairo_t *cr)
 {
-	float alpha;
+	double alpha;
 	if (windata->composited)
 		alpha = BACKGROUND_OPACITY;
 	else
@@ -876,6 +887,7 @@ void
 set_notification_text(GtkWindow *nw, const char *summary, const char *body)
 {
 	char *str;
+	size_t str_len;
 	char* quoted;
 	WindowData *windata = g_object_get_data(G_OBJECT(nw), "windata");
 	g_assert(windata != NULL);
@@ -892,7 +904,8 @@ set_notification_text(GtkWindow *nw, const char *summary, const char *body)
 	xmlInitParser();
 	str = g_strconcat ("<markup>", "<span color=\"#000000\">", body, "</span>", "</markup>", NULL);
 	/* parse notification body */
-	doc = xmlReadMemory(str, strlen (str), "noname.xml", NULL, 0);
+	str_len = strlen (str);
+	doc = xmlReadMemory(str, (int) str_len, "noname.xml", NULL, 0);
 	g_free (str);
 	if (doc != NULL) {
 		xmlXPathContextPtr xpathCtx;
