@@ -3,6 +3,7 @@
  * Copyright (C) 2006-2007 Christian Hammond <chipx86@chipx86.com>
  * Copyright (C) 2009 Red Hat, Inc.
  * Copyright (C) 2011 Perberos <perberos@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -495,6 +496,7 @@ void notification_tick(GtkWindow* nw, glong remaining)
 void set_notification_text(GtkWindow* nw, const char* summary, const char* body)
 {
 	char* str;
+	size_t str_len;
 	char* quoted;
 	GtkRequisition req;
 	WindowData* windata;
@@ -516,7 +518,8 @@ void set_notification_text(GtkWindow* nw, const char* summary, const char* body)
 	xmlInitParser();
 	str = g_strconcat ("<markup>", body, "</markup>", NULL);
 	/* parse notification body */
-	doc = xmlReadMemory(str, strlen (str), "noname.xml", NULL, 0);
+	str_len = strlen (str);
+	doc = xmlReadMemory(str, (int) str_len, "noname.xml", NULL, 0);
 	g_free (str);
 	if (doc != NULL) {
 		xmlXPathContextPtr xpathCtx;
@@ -613,8 +616,8 @@ static GdkPixbuf* scale_pixbuf(GdkPixbuf* pixbuf, int max_width, int max_height,
 		int scale_x;
 		int scale_y;
 
-		scale_x = (int) (pw * scale_factor);
-		scale_y = (int) (ph * scale_factor);
+		scale_x = (int) (((float) pw) * scale_factor);
+		scale_y = (int) (((float) ph) * scale_factor);
 
 		return gdk_pixbuf_scale_simple(pixbuf, scale_x, scale_y, GDK_INTERP_BILINEAR);
 	}
